@@ -995,7 +995,7 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
 
     // set subject
     if (mz.subject != NULL) {
-	if (dg_str2code((char *)mz.subject, &subject, STR_UTF8, STR_JIS) != 0) {
+	if (dg_str2code_replace((char *)mz.subject, &subject, STR_UTF8, STR_JIS) != 0) {
             log(ERR_CHARCODE_CONVERT, "tmpl_tag_replace");
             subject = strdup(NOT_ENC_SUBJECT);
 	    if (subject == NULL) {
@@ -1095,7 +1095,7 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
     // last '\n' change into '\0'
     *(tmpf + total_len - 1) = '\0';
     // store all filename 
-    if (dg_str2code(tmpf, &filename, STR_UTF8, STR_JIS) != 0) {
+    if (dg_str2code_replace(tmpf, &filename, STR_UTF8, STR_JIS) != 0) {
         log(ERR_CHARCODE_CONVERT, "tmpl_tag_replace");
 	filename = strdup(NOT_ENC_ATTACHFILE);
 	if (filename == NULL) {
@@ -1123,7 +1123,7 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
     }
 
     /* Repairing for encoded Subject by MIME encode(2014/05/14(wed)) */
-    if (dg_str2code(tmp_dec, &tmpl, STR_UTF8, STR_JIS) != 0) {
+    if (dg_str2code_replace(tmp_dec, &tmpl, STR_UTF8, STR_JIS) != 0) {
         log(ERR_CHARCODE_CONVERT, "tmpl_tag_replace");
 	free(tmpp);
         free(tmp_dec);
@@ -1153,7 +1153,7 @@ tmpl_tag_replace(char *tmp, struct mailzip mz, struct rcptinfo *other, char *sen
     }
 
     //convert str code
-    if (dg_str2code(tmptagp, retp, STR_UTF8, STR_JIS) != 0) {
+    if (dg_str2code_replace(tmptagp, retp, STR_UTF8, STR_JIS) != 0) {
         log(ERR_CHARCODE_CONVERT, "tmpl_tag_replace");
 	free(tmptagp);
 	return(ERROR);
