@@ -19,9 +19,9 @@
  */
 
 /*
- * $RCSfile: mailzip_tmpl.h,v $
- * $Revision: 1.2 $
- * $Date: 2010/09/27 07:33:44 $
+ * $RCSfile$
+ * $Revision$
+ * $Date$
  */
 
 #include "zipconv.h"
@@ -39,6 +39,13 @@
 #define ERR_FUNC    -1
 #define ERR_VALUE    1
 #define REPLACED_TAG 0
+#define MAIL_SEP "\n\n"
+#define NOT_ENC_SUBJECT "Invalid character code exists in the subject."
+#define NOT_ENC_ATTACHFILE "Invalid character code exists in the attach file."
+#define NOT_ENC_HEADER "%s:Cannot encode header data."
+#define NOT_ENC_TMPL "%s:Cannot encode template file."
+#define BAD_MAIL_TMPL "%s:Cannot separate header part and body part."
+#define NO_HEADER "%s:Cannot find mail header data."
 
 int tmpl_tag_replace(char *, struct mailzip, struct rcptinfo *, char *, char **);
 int tmpl_read(char **, char *);
