@@ -198,8 +198,8 @@ search_rcptaddr(struct config *cfg, char *sender, struct rcptaddr *rcptlist, str
     struct search_res res;
 
     /* Initialization */
-    res.onetime_pass = NULL;
     res.rcpt_dbp = NULL;
+    res.onetime_pass = NULL;
     res.ld = NULL;
     res.userdn = NULL;
 
@@ -212,17 +212,17 @@ search_rcptaddr(struct config *cfg, char *sender, struct rcptaddr *rcptlist, str
 
     /* default policy set */
     if ((cfg->cf_defaultencryption[0] == 'Y') || (cfg->cf_defaultencryption[0] == 'y')) {
-	default_policy = ENC;
+        default_policy = ENC;
         defalt_pass_len = strlen(cfg->cf_defaultpassword);
     }
 
     /* user policy set */
     if ((cfg->cf_userpolicy[0] == 'Y') || (cfg->cf_userpolicy[0] == 'y')) {
-	user_policy = ENC;
+        user_policy = ENC;
 
         /* ldapserver connect */
         res.ld = ldap_connect(cfg->cf_ldapuri, cfg->cf_ldapbinddn, 
-			      cfg->cf_ldapbindpassword);
+                cfg->cf_ldapbindpassword);
         if (res.ld == NULL) {
             free_search_rcptaddr(&res);
             return ERROR;
@@ -230,7 +230,7 @@ search_rcptaddr(struct config *cfg, char *sender, struct rcptaddr *rcptlist, str
 
         /* get userdn */
         ret = ldap_get_userdn(res.ld, cfg->cf_ldapbasedn, sender, rcptaddr, 
-			      cfg->cf_ldapfilter, &res.userdn);
+                cfg->cf_ldapfilter, &res.userdn);
         if ((ret == LDAP_ERROR) || (ret == MALLOC_ERROR)) {
             free_search_rcptaddr(&res);
             return ERROR;
@@ -249,41 +249,137 @@ search_rcptaddr(struct config *cfg, char *sender, struct rcptaddr *rcptlist, str
     for (i = 0; (rcptlist + i)->rcpt_addr != NULL; i++) {
         rcptaddr = (rcptlist + i)->rcpt_addr;
         rcptaddrlen = (rcptlist + i)->rcpt_addr_len;
-	DEBUGLOG("Check Rcpt Addr.(%s)", rcptaddr);
+        DEBUGLOG("Check Rcpt Addr.(%s)", rcptaddr);
 
-	/* Berkeleydb check */
-	ret = search_rcptaddr_bdb(&res, cfg, rcptaddr, passlist, rdmpasslist);
-	if (ret < 0) {
-	    free_search_rcptaddr(&res);
+        /* Berkeleydb check */
+        ret = search_rcptaddr_bdb(&res, cfg, rcptaddr, passlist, rdmpasslist);
+        if (ret < 0) {
+            free_search_rcptaddr(&res);
             return ERROR;
-	} else if (ret != RECORD_NOTFOUND) {
+        } else if (ret != RECORD_NOTFOUND) {
             enc_status = ENC;
-	    continue;
+            continue;
         }
 
-	/* default policy check */
-	if (default_policy == ENC) {
+        /* default policy check */
+        if (default_policy == ENC) {
             enc_status = ENC;
-	    ret = check_default_policy(defalt_pass_len, &res, cfg, rcptaddr, 
-				       passlist, rdmpasslist);
-	    if (ret != ADD_LIST_SUCCESS) {
-	        free_search_rcptaddr(&res);
+            ret = check_default_policy(defalt_pass_len, &res, cfg, rcptaddr, 
+                    passlist, rdmpasslist);
+            if (ret != ADD_LIST_SUCCESS) {
+                free_search_rcptaddr(&res);
                 return ERROR;
-	    }
+            }
             continue;
-	}
+        }
 
-	/* user policy check */
-	if (user_policy == ENC) {
-	    ret = search_rcptaddr_ldap(&res, cfg, rcptaddr, passlist, rdmpasslist);
-	    if (ret == ERROR) {
-	        free_search_rcptaddr(&res);
+        /* user policy check */
+        if (user_policy == ENC) {
+            ret = search_rcptaddr_ldap(&res, cfg, rcptaddr, passlist, rdmpasslist);
+            if (ret == ERROR) {
+                free_search_rcptaddr(&res);
                 return ERROR;
-	    } else if (ret == NOT_ENC) {
-		continue;
-	    }
-	    enc_status = ENC;
-	}
+            } else if (ret == NOT_ENC) {
+                continue;
+            }
+            enc_status = ENC;
+        }
+    } // rcpt addrlist loop
+
+    free_search_rcptaddr(&res);
+
+    return enc_status;
+}
+
+/*
+ * search_rcptaddr_delmode()
+ *
+ * Rcpt addr of RCTPDB is retrieved.
+ *
+ * ------------------------------------------------------------
+ *  DB Search Result | Corresponding Action | Return Value,
+ *  or policy        |                      | i.e., enc_status
+ * ------------------------------------------------------------
+ *  ENC              | DELETE               | ENC
+ *  NOT_ENC          | NOT DELETE           | NOT_ENC
+ * ------------------------------------------------------------
+ *
+ * config *cfg      			cfg pointer
+ * struct rcptaddr *rcptlist		rcpt addr list
+ * struct rcptinfo **passlist		List to delete with dummy password
+ * struct rcptinfo **rdmpasslist        a dummy and empty list 
+ *
+ * return value
+ *       ENC        	Delete.
+ *       NOT_ENC    	Not Delete.
+ *       ERROR   	bdb error
+ *       MALLOC_ERROR   alloc error
+ */
+int
+search_rcptaddr_delmode(struct config *cfg, struct rcptaddr *rcptlist, struct rcptinfo **passlist, struct rcptinfo ** rdmpasslist)
+{
+    int i, ret; 
+    int enc_status = NOT_ENC; 
+    int default_policy = NOT_ENC;
+    char *rcptaddr = NULL;
+    int rcptaddrlen = 0;
+    int pass_len = 0;
+    int defalt_pass_len = 0;
+    struct search_res res;
+
+    /* Initialization */
+    res.rcpt_dbp = NULL;
+    res.onetime_pass = NULL;
+    res.ld = NULL;
+    res.userdn = NULL;
+
+    /* make onetime password */
+    ret = mk_passwd(&res.onetime_pass, pass_len);// res.onetime_pass = '\0' when pass_len = 0.
+    if (ret != PASSWD_SUCCESS) {
+        return MALLOC_ERROR;
+    }
+    DEBUGLOG("Make password ok");
+
+
+    /* default policy set */
+    if ((cfg->cf_defaultdeletepolicy[0] == 'Y') || (cfg->cf_defaultdeletepolicy[0] == 'y')) {
+        default_policy = ENC;
+    }
+
+    /* rcptdb open */
+    ret = db_open(&res.rcpt_dbp, cfg->cf_rcptdbpath, cfg->cf_rcptdbtype);
+    if (ret == DB_ERROR) {
+        free_search_rcptaddr(&res);
+        return ERROR;
+    }
+
+    for (i = 0; (rcptlist + i)->rcpt_addr != NULL; i++) {
+        rcptaddr = (rcptlist + i)->rcpt_addr;
+        rcptaddrlen = (rcptlist + i)->rcpt_addr_len;
+        DEBUGLOG("Check Rcpt Addr.(%s)", rcptaddr);
+
+        /* Berkeleydb check */
+        ret = search_rcptaddr_bdb(&res, cfg, rcptaddr, rdmpasslist, rdmpasslist);
+        if (ret < 0) {
+            free_search_rcptaddr(&res);
+            return ERROR;
+        } else if (ret != RECORD_NOTFOUND) {
+            enc_status = ENC;
+            continue;
+        }
+
+        /* default policy check */
+        if (default_policy == ENC) {
+            // Add address to DELETE list, i.e., rdmpasslist.
+            // Note that no checks works in check_default_policy() in delete mode.
+            ret = check_default_policy(defalt_pass_len, &res, cfg, 
+                                       rcptaddr, rdmpasslist, rdmpasslist);
+            if (ret != ADD_LIST_SUCCESS) {
+                free_search_rcptaddr(&res);
+                return ERROR;
+            }
+            enc_status = ENC;
+        }
     } // rcpt addrlist loop
 
     free_search_rcptaddr(&res);
@@ -553,6 +649,7 @@ add_enclist(struct rcptinfo ***head, char *keyword, char *addr, char *passwd)
             /* set last structure */
             tmpp = p;
 
+            // strncmp returns 0 when p->keyword_len = 0.
             if (strncmp(p->keyword, keyword, p->keyword_len) != 0) {
                 continue;
             }
