@@ -117,12 +117,21 @@ parent(int fd[2], struct mailzip *mz)
     filter = g_mime_filter_crlf_new(TRUE, FALSE);
 
     /* set CFLF filter */
+#ifndef GMIME26
     f_stream = g_mime_stream_filter_new_with_stream(w_stream);
+#else
+    f_stream = g_mime_stream_filter_new(w_stream);
+#endif
+
     g_object_unref (w_stream);
 
     g_mime_stream_filter_add((GMimeStreamFilter *)f_stream, filter);
 
+#ifndef GMIME26
     g_mime_message_write_to_stream(mz->message, f_stream);
+#else
+    g_mime_object_write_to_stream((GMimeObject *)mz->message, f_stream);
+#endif
     g_mime_stream_flush(f_stream);
 
     g_object_unref(filter);
