@@ -986,7 +986,7 @@ DEBUGLOG("Failed to get filename when index = %d", i);
         }
 
 	/* convert str code */
-	if (dg_str2code(tmpname, &tmpfilename, STR_UTF8, cfg->cf_strcode) != 0) {
+	if (dg_str2code_replace(tmpname, &tmpfilename, STR_UTF8, cfg->cf_strcode) != 0) {
             /* START ADD 20150323 */
             /* If the conversion of the str2code is failed, the name of 
              * the attaching file is set by cf_attachmentfilealias.
